#include <avr/io.h>
#include <avr/interrupt.h>
#define F_CPU 16000000UL
#include <util/delay.h>

#define TRX_FRAME_BUFFER(index) (*(volatile uint8_t *)(0x180 + (index)))

volatile uint8_t rxPayload;

uint8_t nod1_address __attribute__((section(".data"))) = 0;
uint8_t node_address __attribute__((section(".data"))) = 0;


void initLeds()
{
	DDRE = 0xff;
	PORTE = 0xff;
}

void setState(uint8_t state)
{
	TRX_STATE = CMD_FORCE_TRX_OFF;
	TRX_STATE = state;
	while (state != TRX_STATUS_struct.trx_status); 
}

// send a short frame with a magic payload
void sendFrame()
{
	setState(CMD_PLL_ON);

	TRX_FRAME_BUFFER(0) = 3;	//length - minimum length is 3
	TRX_FRAME_BUFFER(1) = 42;	//magic payload


	// start transmission
	TRX_STATE = CMD_TX_START;
}


// upon receipt make a simple verification of correctness
ISR(TRX24_RX_END_vect)
{
	rxPayload = TRX_FRAME_BUFFER(0);
	if (rxPayload == 42)
		PORTE ^= (1<<PE2);
	setState(CMD_RX_ON);
}

void rfInit(void)
{
	setState(CMD_TRX_OFF);

	IRQ_STATUS = 0xff;
	IRQ_MASK_struct.rx_end_en = 1;
	sei();

	//PHY_CC_CCA_struct.channel = 0x0b;
	TRX_CTRL_2_struct.rx_safe_mode = 1;
}

int main()
{
	rfInit();
	initLeds();


	if (node_address == 1)
	{
		sendFrame();
		_delay_ms(100);
	}
	else 
	{
		PORTE &= ~(_BV(PE2));
		setState(CMD_RX_ON);
		while (rxPayload != 42) asm("nop");
	}

	return 0;
} 
